Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type CreateResponseMessageCommand ¶
type CreateResponseMessageCommand struct {
AllParticipants []Participant
ResponseParticipantIndex int
ResponseGpt Gpt
Messages []Message
}
type Message ¶
type Message struct {
Content string
Participant Participant
}
type Participant ¶
type Response ¶
type Response struct {
// A unique identifier from the gpt provider.
ExternalID string
// A list of response message choices. Can be more than one if n is greater than 1.
GeneratedMessages []Message
// The Unix timestamp (in seconds) of when the chat completion was Created.
Created int
// Number of tokens in the generated completion.
Response_tokens int
// Number of tokens in the prompt.
Prompt_tokens int
// Total number of tokens used in the request (prompt + completion).
Total_tokens int
}
type Service ¶
type Service interface {
CreateResponseMessage(command CreateResponseMessageCommand) (*Response, error)
}
func NewService ¶
Click to show internal directories.
Click to hide internal directories.